from asset_id import roasset *
from creator import roasset *
from creator_id import roasset *
from is_public import roasset *
from product_id import roasset *
from name import roasset *
from description import roasset *
from asset_type_id import roasset *
from created_at import roasset *
from last_updated import roasset *
from price_in_robux import roasset *
from sales import roasset *
from is_new import roasset *
from is_for_sale import roasset *
from is_limited import roasset *
from remaining import roasset *
from thumbnail import roasset *
from assetloc import roasset *